summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorMalcolm Priestley2014-05-31 00:22:47 +0200
committerGreg Kroah-Hartman2014-06-20 00:56:48 +0200
commit4a9f4c655cd7aeebd81714c4cd8af165657cf6ed (patch)
tree3bdbf9f53c1c04d34dcf118783cdc55b33245f35
parentstaging: vt6656: rename CARDvAdjustTSF to vnt_adjust_tsf (diff)
downloadkernel-qcow2-linux-4a9f4c655cd7aeebd81714c4cd8af165657cf6ed.tar.gz
kernel-qcow2-linux-4a9f4c655cd7aeebd81714c4cd8af165657cf6ed.tar.xz
kernel-qcow2-linux-4a9f4c655cd7aeebd81714c4cd8af165657cf6ed.zip
staging: vt6656: rename CARDbGetCurrentTSF to vnt_get_current_tsf
Drop card and rename to vnt_get_current_tsf Signed-off-by: Malcolm Priestley <tvboxspy@gmail.com> Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>
-rw-r--r--drivers/staging/vt6656/card.c4
-rw-r--r--drivers/staging/vt6656/card.h2
-rw-r--r--drivers/staging/vt6656/wmgr.c6
3 files changed, 6 insertions, 6 deletions
diff --git a/drivers/staging/vt6656/card.h b/drivers/staging/vt6656/card.h
index 75e4f5f9af79..89bbc704c333 100644
--- a/drivers/staging/vt6656/card.h
+++ b/drivers/staging/vt6656/card.h
@@ -52,7 +52,7 @@ void vnt_update_top_rates(struct vnt_private *);
void vnt_add_basic_rate(struct vnt_private *, u16);
int vnt_ofdm_min_rate(struct vnt_private *);
void vnt_adjust_tsf(struct vnt_private *, u8, u64, u64);
-bool CARDbGetCurrentTSF(struct vnt_private *pDevice, u64 *pqwCurrTSF);
+bool vnt_get_current_tsf(struct vnt_private *, u64 *);
bool CARDbClearCurrentTSF(struct vnt_private *pDevice);
void CARDvSetFirstNextTBTT(struct vnt_private *pDevice, u16 wBeaconInterval);
void CARDvUpdateNextTBTT(struct vnt_private *pDevice, u64 qwTSF,
diff --git a/drivers/staging/vt6656/wmgr.c b/drivers/staging/vt6656/wmgr.c
index d5d227385a43..55b92fe1ec85 100644
--- a/drivers/staging/vt6656/wmgr.c
+++ b/drivers/staging/vt6656/wmgr.c
@@ -1944,9 +1944,9 @@ if(ChannelExceedZoneType(pDevice,byCurrChannel)==true)
// endian issue ???
// Update TSF
if (bUpdateTSF) {
- CARDbGetCurrentTSF(pDevice, &qwCurrTSF);
+ vnt_get_current_tsf(pDevice, &qwCurrTSF);
vnt_adjust_tsf(pDevice, pRxPacket->byRxRate, qwTimestamp , pRxPacket->qwLocalTSF);
- CARDbGetCurrentTSF(pDevice, &qwCurrTSF);
+ vnt_get_current_tsf(pDevice, &qwCurrTSF);
CARDvUpdateNextTBTT(pDevice, qwTimestamp, pMgmt->wCurrBeaconPeriod);
}
@@ -2044,7 +2044,7 @@ void vMgrCreateOwnIBSS(struct vnt_private *pDevice, PCMD_STATUS pStatus)
pMgmt->wIBSSBeaconPeriod = DEFAULT_IBSS_BI;
MACvWriteBeaconInterval(pDevice, pMgmt->wIBSSBeaconPeriod);
- CARDbGetCurrentTSF(pDevice, &qwCurrTSF);
+ vnt_get_current_tsf(pDevice, &qwCurrTSF);
// clear TSF counter
CARDbClearCurrentTSF(pDevice);
diff --git a/drivers/staging/vt6656/card.c b/drivers/staging/vt6656/card.c
index 24dd9f829262..c746677a9e7e 100644
--- a/drivers/staging/vt6656/card.c
+++ b/drivers/staging/vt6656/card.c
@@ -29,7 +29,7 @@
* CARDvSetLoopbackMode - Set Loopback mode
* CARDbSoftwareReset - Sortware reset NIC
* vnt_get_tsf_offset - Calculate TSFOffset
* CARDbGetCurrentTSF - Read Current NIC TSF counter
* CARDqGetNextTBTT - Calculate Next Beacon TSF counter
* CARDvSetFirstNextTBTT - Set NIC Beacon time
* CARDvUpdateNextTBTT - Sync. NIC Beacon time
@@ -614,7 +614,7 @@ void vnt_adjust_tsf(struct vnt_private *priv, u8 rx_rate,
* Return Value: true if success; otherwise false
*
*/
-bool CARDbGetCurrentTSF(struct vnt_private *priv, u64 *current_tsf)
+bool vnt_get_current_tsf(struct vnt_private *priv, u64 *current_tsf)
{
*current_tsf = priv->qwCurrTSF;
@@ -29,7 +29,7 @@
* CARDbSoftwareReset - Sortware reset NIC
* vnt_get_tsf_offset - Calculate TSFOffset
- * CARDbGetCurrentTSF - Read Current NIC TSF counter
+ * vnt_get_current_tsf - Read Current NIC TSF counter
* CARDqGetNextTBTT - Calculate Next Beacon TSF counter
* CARDvSetFirstNextTBTT - Set NIC Beacon time